;NSIS Modern User Interface
;Basic Example Script
;Written by Tudor Holton

!ifndef VERSION
!warning "VERSION not defined."
!define VERSION 0
!endif

;--------------------------------
;Include Modern UI

  !include "MUI2.nsh"

;--------------------------------
;General

  ;Name and file
  OutFile "OpenScore-${RELEASETYPE}-Windows-x86-${VERSION}.exe"
  Name "OpenScore"

  ;Request application privileges for Windows Vista
  RequestExecutionLevel highest

  ;Default installation folder
  InstallDir "$PROGRAMFILES\OpenScore"
  
  ;Get installation folder from registry if available
  InstallDirRegKey HKCU "Software\OpenScore" ""


;--------------------------------
;Interface Settings

  !define MUI_HEADERIMAGE
  !define MUI_HEADERIMAGE_BITMAP "openscore.bmp" ; optional
  !define MUI_ABORTWARNING

;--------------------------------
;Pages

  !insertmacro MUI_PAGE_LICENSE "LICENSE.txt"
  !insertmacro MUI_PAGE_COMPONENTS
  !insertmacro MUI_PAGE_DIRECTORY
  !insertmacro MUI_PAGE_INSTFILES
;  !insertmacro MUI_PAGE_FINISH
  
  !insertmacro MUI_UNPAGE_CONFIRM
  !insertmacro MUI_UNPAGE_INSTFILES
;  !insertmacro MUI_UNPAGE_FINISH
  
;--------------------------------
;Languages
 
  !insertmacro MUI_LANGUAGE "English"

;--------------------------------
;Installer Sections

Section "OpenScore" SecMain ; Starting name with "-" means it will always be installed.
  SetShellVarContext all

  SetOutPath "$INSTDIR"  

  ;ADD YOUR OWN FILES HERE...
  SetOverwrite on
  File /r "OpenScore.jar"
  File /r "LICENSE.txt"
  File /r "openscore.ico"
  File /r "openscore.bmp"
  File /r "org.eclipse.swt.win32.win32.x86.jar"
  File /r "org.eclipse.swt.jar"
  File /r "org.eclipse.jface.jar"
  File /r "org.eclipse.osgi.jar"
  File /r "org.eclipse.equinox.common.jar"
  File /r "org.eclipse.core.commands.jar"
  File /r "org.eclipse.ui.workbench.jar"
  File /r "jdom.jar"
  File /r "org.josql.jar"
  File /r "gentlyWEB-utils-1.1.jar"
  File /r "RXTXcomm.jar"
  File /r "rxtxSerial.dll"

  SetOutPath "$INSTDIR\bin"
  File /r "bin\maintitle.gif"
  File /r "bin\delete.gif"
  File /r "bin\add.gif"
  File /r "bin\checked.gif"
  File /r "bin\unchecked.gif"

  SetOutPath "$INSTDIR"
  
  ; Write the installation path into the registry
  WriteRegStr HKLM SOFTWARE\NSIS_OpenScore "Install_Dir" "$INSTDIR"
  
  ; Write the uninstall keys for Windows
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\OpenScore" "DisplayName" "OpenScore"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\OpenScore" "UninstallString" '"$INSTDIR\uninstall.exe"'
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\OpenScore" "NoModify" 1
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\OpenScore" "NoRepair" 1

  ;Create uninstaller
  WriteUninstaller "$INSTDIR\Uninstall.exe"

SectionEnd

; Optional section (can be disabled by the user)
Section "Desktop Shortcuts"
  SetShellVarContext all

;  SetOverwrite on
  CreateShortCut "$DESKTOP\OpenScore.lnk" "javaw" "-Xmx300m -jar OpenScore.jar" "$INSTDIR\openscore.ico" 0
  CreateShortCut "$DESKTOP\OpenScore (Debug Mode).lnk" "java" "-Xmx300m -jar OpenScore.jar --debug" "$INSTDIR\openscore.ico" 0
SectionEnd


; Optional section (can be disabled by the user)
Section "Start Menu Shortcuts"
  SetShellVarContext all

;  SetOverwrite on
  CreateDirectory "$SMPROGRAMS\OpenScore"
  CreateShortCut "$SMPROGRAMS\OpenScore\OpenScore.lnk" "javaw" "-Xmx300m -jar OpenScore.jar" "$INSTDIR\openscore.ico" 0
  CreateShortCut "$SMPROGRAMS\OpenScore\OpenScore (Debug Mode).lnk" "java" "-Xmx300m -jar OpenScore.jar --debug" "$INSTDIR\openscore.ico" 0
  ; CreateShortCut "$SMPROGRAMS\OpenScore\Uninstall.lnk" "$INSTDIR\uninstall.exe" "" "$INSTDIR\uninstall.exe" 0  
SectionEnd

;--------------------------------
;Descriptions

  ;Language strings
  LangString DESC_SecMain ${LANG_ENGLISH} "A test section."

  ;Assign language strings to sections
  !insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
    !insertmacro MUI_DESCRIPTION_TEXT ${SecMain} $(DESC_SecMain)
  !insertmacro MUI_FUNCTION_DESCRIPTION_END

;--------------------------------
;Uninstaller Section

Section "Uninstall"
  SetShellVarContext all

  ;ADD YOUR OWN FILES HERE...

  Delete "$INSTDIR\Uninstall.exe"

  ; Remove the bin dir
  Delete $INSTDIR\bin\*.*
  
  ; Remove files and uninstaller
  Delete $INSTDIR\*.*

  RMDir "$INSTDIR\bin"
  RMDir "$INSTDIR"

  ; Remove registry keys
  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\OpenScore"
  DeleteRegKey HKLM SOFTWARE\NSIS_OpenScore

  ; Remove shortcuts, if any
  Delete "$SMPROGRAMS\OpenScore\*.*"

  ; Remove directories used
  RMDir "$SMPROGRAMS\OpenScore"
  RMDir "$INSTDIR"

SectionEnd
