# $Id$

#usage playout->$method(client => 'Flywire' or 'Novation',
#				  arguments => ...
#				  );

# /** Handles transactions between Retromod and playout client installations. */
package playout;

use strict;
use playout::Client;
use playout::Storage;
use playout::Exception;
use Retromod::Constant;
use Retromod::Global;

our $AUTOLOAD;

my %fields = (
	component => undef,
	moduleID => undef,
);

# /** Autoload that also fetches methods from defined client class. */
sub AUTOLOAD {
	my $self = shift;
	my $type = ref($self)
		or die("$self is not an object");

	my $name = $AUTOLOAD;
	# Strip fully-qualified portion.
	$name =~ s/.*://;

	# try {

	# If method is not in the predefined variables, try return the
	#   appropriate method for the requested client instead.
	unless (exists $self->{_permitted}->{$name} ) {
		# print "Can't access `$name' field in class $type.\n";
		# print "Attempting to fetch the method...\n";

		my $client = shift;
		# /** @todo Return an array of args instead. */

		# print $client." client\n";

		my $client_handler = playout::Client->new($client);

		# Set variables.
		$client_handler->moduleID($self->moduleID);
		$client_handler->component($self->component);

		# Check that the desired playout client exists.
		eval {
			$client_handler->resolve_client_class();
		};
		if ($@) {
			print $@->getErrorMessage();
			exit();
		}

		# Retrieve the client installations for this playout client.
		my @install_array = $client_handler->installs();
		# print @install_array;

		# Execute the requested method for each install of the playout client.
		foreach my $client_install (@install_array) {

			# Check if method exists.
			unless ($client_install->can($name) ) {
				die playout::Exception->new("Cannot access the method '$name' field in class $client (via the class $type)");
			}
			if ($@) {
				print $@->getErrorMessage();
				return 0;
			}
			# print "The method $name exists in class $client.\n";

			# Retrieve storage information.
			eval {
				$client_handler->fetch_storage_params($client_install) || die playout::Exception->new("Unable to retrieve storage information.");
			};
			if ($@) {
				print $@->getErrorMessage();
				return 0;
			}

			# Execute the method.
			eval {
				# TEMPORARY execution without arguments.
				$client_install->$name() || die playout::Exception->new("Unable to execute. Method did not return true value.");
			};
			if ($@) {
				print $@->getErrorMessage();
				return 0;
			}

			# /** @todo Pass through all args to method. */

			# if (@args) {
				# $client_install->$name(@args);
			# } else {
				# $client_install->$name();
			# }
		}
		print "Operation complete.\n";
		return 1;
	}
	if (@_) {
		return $self->{$name} = shift;
	} else {
		return $self->{$name};
	}
}

# /** Constructor. */
sub new {
	my $that = shift;
	my $class = ref($that) || $that;

	# $fields{component} = shift;
	# $fields{client_method} = shift;
	# $fields{client_type} = shift;
	# if (@_) {
		# $fields{client_args} = join(", ", @_);
	# }

	# /** @todo Return an array of args instead. */

	my $self = {
		_permitted => \%fields,
		%fields,
	};

	# print $self->component();
	# print $self->moduleID();
	# print $self->client_type();

	# $self->test();

	# my $client = playout::Client->new();
	# print $client;

	bless ($self, $class);
	return $self;
}

# sub test {
	# my($self, $args) = @_;
	# # /** @todo Receive args as array. */
	# my @args = split(', ', $args);
	# print "This is playout->test"."\n";
	# print "and these are the args: @args"."\n";
	# print $self->component()."\n";
	# print $self->client_type()."\n";
	# print $self->client_method()."\n";
# }

# /** Returns the storage class to share storage methods with other components. */
sub share_storage {
	my $self = shift;
	my $store = playout::Storage->new();
	return $store;
}

# /** Help page. */
sub help {
	my $self = shift;
	my $client = shift;
	my $exists = 1;

	my $help_message = <<EOH;
This is the help for the playout component of Retromod.

The playout component must be used with the argument of client.

Usage: update.pl playout method client [ arguments ]

  Client:
    The case sentitive alphanumeric identifier of a valid playout client.
    E.g. Flywire

  Method:
  help
    Returns this help page.
  share_storage
    Returns the storage class for the traffic component.

EOH

	# If client argument exists print client's help method instead.
	my $client_handler = playout::Client->new($client);
	
	my $client_install;
	# Check that the desired playout client exists.
	eval {
		$client_install = $client_handler->resolve_client_class();
	};
	if ($@) {
		my $exists = 0;
		print "$help_message\n";
	}

	if ($exists) {
		# Check if method exists.
		$client_install = $client_handler->resolve_client_class();
		if ($client_install->can('help')) {
			$client_install->help();
		} else {
			print "$help_message\n";
		}
	}
}

# /** Destructor. */
sub DESTROY {
	my ($self) = @_;
}

1;