# $Id$

use playout;
use playout::Exception;

#usage playout::Client->new( client => 'Flywire' or 'Novation"...);

# /** Handles interfacing with playout clients. */
package playout::Client;

# Specify parent for inheritance.
@ISA = (playout);

use strict;
use playout::Storage;

our $AUTOLOAD;

my %fields = (
	client => undef,
	params => undef,
	component => undef,
	moduleID => undef,
);

# /** Autoload. */
sub AUTOLOAD {
	my $self = shift;
	my $type = ref($self)
		or die("$self is not an object");

	my $name = $AUTOLOAD;
	# Strip fully-qualified portion.
	$name =~ s/.*://;

	unless (exists $self->{_permitted}->{$name} ) {
		die("Can't access `$name' field in class $type");
	}

	if (@_) {
		return $self->{$name} = shift;
	} else {
		return $self->{$name};
	}
}

# /** Destructor. */
sub DESTROY {
	my ($self) = @_;
}

# /** Constructor. */
sub new {
	my $that = shift;
	my $class = ref($that) || $that;
	$fields{client} = shift;
	my $self = {
		_permitted => \%fields,
		%fields,
	};

	bless ($self, $class);
	return $self;
	# /** @todo Return an array of objects. */
}

# /** Resolves the appropriate module for a given client. eg. playout::Client::Flywire. */
sub resolve_client_class {
	my $self = shift;

	my $client = $self->client();
	my $file = join("", "playout/Client/", $client, ".pm");
	my $class = "playout::Client::".$client;

	# Load component package as Perl module.
    my ($error, $failed);
    {
        local $@;
        $failed = not eval { require $file; 1; };
        $error = $@;
    }
    if ($failed) {
		die playout::Exception->new("Cannot access the class '$client'.");
		return 0;
	} else {
		# Create new object.
		my $object = $class->new();

		return $object;
	}

}

# /** Fetch the client-defined parameters. */
sub fetch_params {
	my $self = shift;
	my $client = $self->client();

	my $store = playout::Storage->new();
	my $dbh = Retromod::DB->connect;
	my $query = "
		SELECT I.".$store->{playout_install_params}." AS params
		FROM (".$store->{table_playout_install}." I,
			".$store->{table_playout_client}." C
		)
		WHERE C.".$store->{playout_client_name}." = '".$client."'
		AND I.".$store->{playout_install_client}." = C.".$store->{playout_client_id}."
	";
	# print $query."\n";
	my $result = $dbh->prepare($query);
	$result->execute;

	my $i = 0;
	my %array;
	while (my $line = $result->fetchrow_hashref) {

	    # print $$line{'params'}."\n";

		# Construct return array.
		$array{$i} = $$line{'params'};
		$i++;
	}

	Retromod::DB->disconnect($dbh);
	return %array;
}

# /** Fetch the global storage parameters. */
sub fetch_storage_params($) {
	my $self = shift;
	my $client = shift;

	# Database handle.
	$client->dbh(Retromod::DB->connect);
	# playout component storage methods.
	$client->store(playout::Storage->new());
	# traffic component storage methods.
	my $rht = Retromod->new('traffic', 'share_storage', '');
	$client->trafficStore($rht->return());
	# # production component storage methods.
	# my $rhp = Retromod->new('production', 'share_storage', '');
	# $client->productionStore($rhp->return());

	# Array containing @storage_method = (['modules' or 'components'], [moduleID or componentID]).
	# $client->storage_method(Retromod::Global->resolve_storage_method($self->moduleID));

	# /** @todo Because the storage is determined by traffic and not playout, we are assuming for now
	#    that storage is by components. Without knowing which moduleID we wouldn't be able to determine
	#    storage by modules anyway. */
	$client->storage_method("components");

	# Server-side data storage and cache.
	$client->storage_path(Retromod::Global->escape_string(Retromod::Constant->MEDIASTORE.$client->storage_method));
	$client->cache_path(Retromod::Global->escape_string(Retromod::Constant->MEDIACACHE.$client->storage_method));
}

# /** Return array of client installs. */
sub installs {
	my $self = shift;

	# Fetch a list of the parameters required for each install of the desired client.
	my %installs = $self->fetch_params();
	# print %installs;

	my ($k, $params, @objects);
	while (($k, $params) = each %installs) {
		# print "$k=$params\n";

		# Create a new client install object for each install.

		my $install_obj = $self->resolve_client_class();
		if (!$install_obj) {
			die playout::Exception->new("Cannot proceed. Please check that the client type exists.");
		}
		if ($@) {
			print $@->getErrorMessage();
			return 0;
		}
		# print $install_obj."\n";

		# print "BEFORE: $params\n";

		# Strip any enclosing apostrophes from strings.
		$params =~ s/'//g;
		# Contruct associative array.
		my %params = map { split m{\s*,\s*} } split m{\s*=\>\s*}, $params;
		# /** @todo Make this regex more robust to input. */

		my ($key, $value);
		while (($key, $value) = each %params) {
			# print "KEY: $key => VALUE: $value\n";

			# Assign parameters to client install.
			$install_obj->$key($value);
			# print $install_obj->$key()."\n";
		}
		# Create an array of objects.
		push(@objects, $install_obj);
	}

	return @objects;
}

1;