# $Id$

use playout::Client;

# /** Update module for the scheduled sponsorship data that goes to and from Dinesat on the client machine. */
package playout::Client::Dinesat;

# Specify parent for inheritance.
@ISA = (playout::Client);

use strict;
use playout::Storage;
use XBase;

our $AUTOLOAD;

my %fields = (
	ip => undef,
	log_path => undef,
	media_path => undef,
	schedule_path => undef,
	storage_path => undef,
);

#Temporary allocation of slots.  This should really be pulled from the database.
my %slots = ( "00:05:00", "00:15:00", "00:30:00", "00:45:00", "01:05:00", "01:20:00", "01:35:00", "01:50:00", "02:00:00", "02:30:00", "03:00:00", "03:30:00", "04:00:00", "04:30:00", "05:00:00", "05:30:00", "06:00:00", "06:15:00", "06:30:00", "06:45:00", "07:05:00", "07:20:00", "07:35:00", "07:50:00", "08:05:00", "", "08:20:00", "", "08:35:00", "", "08:50:00", "", "09:00:00", "09:15:00", "09:30:00", "09:45:00", "10:05:00", "10:20:00", "10:35:00", "10:50:00", "11:00:00", "11:15:00", "11:30:00", "11:45:00", "12:05:00", "12:20:00", "12:35:00", "12:50:00", "13:00:00", "13:15:00", "", "13:30:00", "13:45:00", "14:05:00", "14:20:00", "14:35:00", "14:50:00", "15:00:00", "15:15:00", "", "15:30:00", "", "15:45:00", "", "16:05:00", "", "16:20:00", "", "16:35:00", "16:50:00", "17:00:00", "17:15:00", "", "", "17:30:00", "", "17:45:00", "", "", "18:05:00", "", "", "18:20:00", "", "", "18:35:00", "", "", "18:50:00", "", "19:00:00", "19:15:00", "19:30:00", "19:45:00", "20:00:00", "20:15:00", "", "20:30:00", "20:45:00", "21:05:00", "21:20:00", "21:35:00", "21:50:00", "22:00:00", "22:15:00", "", "22:30:00", "22:45:00", "23:05:00", "23:20:00", "23:35:00", "23:50:00" );


/** Example XBase Code
use XBase;
  my $table = new XBase "dbase.dbf" or die XBase->errstr;
  for (0 .. $table->last_record) {
        my ($deleted, $id, $msg)
                = $table->get_record($_, "ID", "MSG");
        print "$id:\t$msg\n" unless $deleted;
    $table->set_record_hash(8, "jezek" => "jezecek",
                                        "krtek" => 5);
}
**/

# /** Constructor. */
sub new {
	# Use our inherited AUTOLOAD but allow set and get of our params.
	my $class = shift;
	my $self = $class->SUPER::new();
	my($element);
	foreach $element (keys %fields) {
		$self->{_permitted}->{$element} = $fields{$element};
	}
	@{$self}{keys %fields} = values %fields;
	return $self;
}

# /** Test. */
sub test {
	print "This is playout::Client::Dinesat->test()!\n";

    my $time = Time::localtime();
    my $date = $time->day().$time->month().$time->year();
    my $table = new XBase "P".$date."B.dbf" or die XBase->errstr;

    my $newtable = XBase->create(
        "name" => "P".$date."B.dbf",
        "field_names" => [ "PLY_SERV", "PLY_CODE",	"PLY_PGMTME",	"PLY_TYPE",	"PLY_DESC",	"PLY_INDEX",	"PLY_STATUS",	"PLY_ICODE",	"PLY_OCODE" ],
        "field_types" => [ "C", "C", "C", "N", "C","C", "N", "C","C" ],
        "field_lengths" => [ 6, 8, 8, 3, 30, 15, 3, 8, 8 ],
        "field_decimals" => [ undef, undef, undef, 0, undef, undef, 0, undef, undef ]
    );

    my $i = 1;
    foreach $slot (%slots) {
        $newtable->set_record_hash($i
            "PLY_SERV" => "",
            "PLY_CODE" => "",
        	"PLY_PGMTME" => "",
	        "PLY_TYPE" => "",
	        "PLY_DESC" => "",
	        "PLY_INDEX" => "",
	        "PLY_STATUS" => "",
	        "PLY_ICODE" => "",
	        "PLY_OCODE" => ""
        );
        $i++;
    }
}

1;
